import { Text, View } from "@tarojs/components";
import { memo } from "react";
import AmountShow from "../amountShow";
import classnames from "classnames";
import styles  from './index.module.scss'

import MCheckbox from "@/components/checkbox";
import Popup from "@/components/popup";
import SearchInput from "@/components/searchInput";
import Taro from "@tarojs/taro";

type Param = {
    show?: true|false,
    onClose?: () => void,
    offlineInfo?: {
        account_name: string,
        bank_of_deposit: string,
        transfer_remittance_account: string
    }
}
export default memo(({show = true, onClose, offlineInfo}:Param) => {
    //复制功能
    const clipboardData = () => {
        Taro.setClipboardData({
            data: `开户名称：${offlineInfo?.account_name};\n\r 开户银行：${offlineInfo?.bank_of_deposit};\n\r 转账汇款账号：${offlineInfo?.transfer_remittance_account};`,
            success: function (res) {
                Taro.showToast({
                    icon: 'none',
                    title: '复制成功'
                })
            }
        })
    }
    return (
        <View className={styles.offlinePay_main}>
            <Popup show={show} showTitle={false} onClose={onClose} >
                <View className={styles.offlinePay_con}>
                    <View className={classnames('iconfont icon-a-moreback', styles.miconfont_title)} onClick={onClose}></View>
                    <View className={styles.title}>线下汇款</View>
                    <View className={styles.offlinePay_list}>
                        <SearchInput showBorder={false} title='开户名称' titleStyle={{fontSize:'23rpx'}}>
                            <Text className={styles.offlinePay_con_text}>{offlineInfo?.account_name}</Text>
                        </SearchInput>
                        <SearchInput showBorder={false} title='开户银行' titleStyle={{fontSize:'23rpx'}}>
                            <Text className={styles.offlinePay_con_text}>{offlineInfo?.bank_of_deposit}</Text>
                        </SearchInput>
                        <SearchInput showBorder={false} title='转账汇款账号' titleStyle={{fontSize:'23rpx'}}>
                            <Text className={styles.offlinePay_con_text}>{offlineInfo?.transfer_remittance_account}</Text>
                        </SearchInput>
                    </View>
                    <View className={styles.btns} onClick={clipboardData}>复制信息</View>
                </View>
            </Popup>
        </View>
        
    )
})